#Licensed Materials - Property of IBM 
#Rational ClearQuest 
#Copyright IBM Corp. 2008, 2009 All Rights Reserved 

package cqcli::Exception;


use cqcli::IOHandler;
use Error qw(:try);
use overload ('""' => 'stringify');
use 5.008006;
use strict;
require Exporter;
our @ISA = qw(Error Exporter);
our $VERSION = '0.01';

  sub new
  {
    my $class = shift;
    my $text = "" . shift;
	my ($pkg , $file , $line) = @_;
    my @args = ();

    local $Error::Depth = $Error::Depth + 1;
    local $Error::Debug = 1;  # Enables storing of stacktrace
	
	my %hval = (-text => $text,
				-ptrace => "" ,
				-jtrace => "" ,
				-rtrace => ""   ,
				-errtext => $text,
				-jerrtext => undef,
				);
	$hval{'-package'} = $pkg if ($pkg); 
	$hval{'-file'} = $pkg if ($file); 
	$hval{'-line'} = $pkg if ($line); 

	
    $class->SUPER::new(%hval, @args);
	
  }

sub printErrorMessage()
{
	my $self = shift;
	CLIprinterror("$self->{'-errtext'}\n");
}

sub appendErrorMessage
{
	my ($self,$ermsg) = @_;
	if($self->{'-errtext'}) {
		$self->{'-errtext'} = $self->{'-errtext'}."\n".$ermsg;
	}else {
		$self->{'-errtext'} = $ermsg;
	}
}

sub setErrorMessage
{
	my ($self,$ermsg) = @_;
	$self->{'-errtext'} = $ermsg;
}

sub setJavaErrorMessage
{
	my ($self,$ermsg) = @_;
	$self->{'-jerrtext'} = $ermsg;
}

#manager methods
sub setMessage
{
	my ($self , $msg) = @_;
	$self->{'-text'} = $msg;

}

sub setJavaStackTrace
{
	my ($self , $tracemsg) = @_;
	$self->{'-jtrace'} = $tracemsg;
	if(!($self->{'_setJavaStackTrace'}{__PACKAGE__})) {
		$self->{'-rtrace'} ="JAVA Stack Trace: "."\n".$tracemsg."\n"."PERL Stack Trace: "."\n".$self->stacktrace();
		$self->{'_setJavaStackTrace'}{__PACKAGE__} = 1;
	}
	else{
		$self->{'-rtrace'} = "JAVA Stack Trace: "."\n".$self->{'-jtrace'}."\n".$self->{'-rtrace'};
	}
}

sub prependMessage
{
	my ($self , $msg) = @_;
	$self->{'-text'} = $msg."\n".$self->{'-text'}."\n";

}
sub appendMessage
{
	my ($self , $msg) = @_;
	$self->{'-text'} = $self->{'-text'}."\n".$msg."\n";

}

sub appendJavaMessage
{
	my ($self , $msg) = @_;
	$self->{'-text'} = $self->{'-text'}."\n".$msg."\n";

}

#Accessor mothods

sub getMessage
{
	my $self = shift;
	return $self->{'-text'};
}

sub printMessage
{
	my $self = shift;
	CLIprinterror("$self->{'-errtext'}\n");
	if( ($self->{'-jerrtext'}) && ($ENV{'CQCLI_ERR_LEVEL'}) && ($ENV{'CQCLI_ERR_LEVEL'} >= 1) ) {
		CLIprinterror("$self->{'-jerrtext'}\n");
	}
}

sub printStackTrace()
{
	my $self = shift;
	my $out = undef;

	if(!($self->{'-rtrace'} eq "")) {
		$out = $self->{'-rtrace'};
	}
	else {
		$out = "PERL Stack Trace: "."\n".$self->stacktrace();
	}

	if(($ENV{'CQCLI_ERR_LEVEL'}) && ($ENV{'CQCLI_ERR_LEVEL'} >= 2) ) {
		CLIprinterror("$out\n");
	}
	

}

sub printPerlStackTrace()
{
	my $self = shift;
	my $out = "PERL Stack Trace: "."\n".$self->stacktrace();
	CLIprinterror("$out\n");
}

sub printJavaStackTrace()
{
	my $self = shift;
	my $out = "JAVA Stack Trace: "."\n".$self->{'-jtrace'};
	CLIprinterror("$out\n");
}

    

package cqcli::ValidationException;

@cqcli::ValidationException::ISA = qw(cqcli::Exception);

package cqcli::SyntaxErrorException;

@cqcli::SyntaxErrorException::ISA = qw(cqcli::Exception);

package cqcli::ParseException;

@cqcli::ParseException::ISA = qw(cqcli::Exception);

package cqcli::JavaException;

@cqcli::JavaException::ISA = qw(cqcli::Exception);

package cqcli::PerlException;

@cqcli::PerlException::ISA = qw(cqcli::Exception);

package cqcli::SessionException;

@cqcli::SessionException::ISA = qw(cqcli::Exception);

package cqcli::UnknownException;

@cqcli::UnknownException::ISA = qw(cqcli::Exception);
###################################################################
package cqcli::UsageException;

use cqcli::IOHandler;
use Pod::Usage;

@cqcli::UsageException::ISA = qw(cqcli::Exception);

sub SetCmdInfo
{
	my $self = shift;
	my ($cmd ,$help) = @_;
	$self->{'-cmd'} = $cmd;
	$self->{'-help'} = $help;
	return 1;
}

sub printMessage
{
	my $self = shift;
	$self->printUsageInfo();
	return 1;
}
sub printUsageInfo
{
	cqcli::Util::CLIPrint_help_message();
	return 1;
}

sub GetLocalePodFile()
{
	my $self = shift;
	my $cmdName = $self->{'-cmd'};
	#handle for locale specific pod filename in future
	return $cmdName."."."pod";

}

sub GetLocaleCQCLIManDir()
{
	my $self = shift;
	
	#handle for locale specific dir name in future
	if(!($ENV{CQCLI_MAN_DIR})) {
		return $ENV{PATH};
	}
	return $ENV{CQCLI_MAN_DIR};
}
#####################################################################
  # try
 


# Preloaded methods go here.

# Autoload methods go after =cut, and are processed by the autosplit program.

1;
__END__
